@@ -21,8 +21,9 @@ function(Symbols=NULL,
                 'getOptions("getSymbols.auto.assign") are now checked for alternate defaults\n\n',
                 'This message is shown once per session and may be disabled by setting \n',
                 'options("getSymbols.warning4.0"=FALSE). See ?getSymbol for more details'))
-        options("getSymbols.warning4.0"=FALSE)
+        options("getSymbols.warning4.0"=FALSE) 
       }
+      importDefaults("getSymbols")
       #  to enable as-it-was behavior, set this:
       #  options(getSymbols=list(env=substitute(parent.frame(3))))
 
@@ -95,7 +96,7 @@ function(Symbols=NULL,
                                            ...))
           if(!auto.assign)
             return(symbols.returned)
-          for(each.symbol in symbols.returned) all.symbols[[each.symbol]] <- symbol.source
+          for(each.symbol in symbols.returned) all.symbols[[each.symbol]] <- symbol.source 
         }
         req.symbols <- names(all.symbols)
         all.symbols <- c(all.symbols,old.Symbols)[unique(names(c(all.symbols,old.Symbols)))]
@@ -122,6 +123,7 @@ formals(loadSymbols) <- loadSymbols.formals
 #                              bb.suffix="Equity",
 #                              bb.interval="5",
 #                              ...) {
+#    importDefaults("getSymbols.Bloomberg")
 #    this.env <- environment()
 #    for(var in names(list(...))) {
 #       # import all named elements that are NON formals
@@ -217,6 +219,7 @@ function(Symbols,env,return.class='xts',index.class="Date",
          to=Sys.Date(),
          ...)
 {
+     importDefaults("getSymbols.yahoo")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
@@ -229,9 +232,9 @@ function(Symbols,env,return.class='xts',index.class="Date",
      default.from <- from
      default.to <- to
 
-     if(missing(verbose)) verbose <- FALSE
-     if(missing(auto.assign)) auto.assign <- TRUE
-     yahoo.URL <- "http://chart.yahoo.com/table.csv?"
+     if(!hasArg(verbose)) verbose <- FALSE
+     if(!hasArg(auto.assign)) auto.assign <- TRUE
+     yahoo.URL <- "http://ichart.finance.yahoo.com/table.csv?"
      for(i in 1:length(Symbols)) {
        return.class <- getSymbolLookup()[[Symbols[[i]]]]$return.class
        return.class <- ifelse(is.null(return.class),default.return.class,
@@ -240,14 +243,14 @@ function(Symbols,env,return.class='xts',index.class="Date",
        from <- if(is.null(from)) default.from else from
        to <- getSymbolLookup()[[Symbols[[i]]]]$to
        to <- if(is.null(to)) default.to else to
-
+   
        from.y <- as.numeric(strsplit(as.character(as.Date(from,origin='1970-01-01')),'-',)[[1]][1])
        from.m <- as.numeric(strsplit(as.character(as.Date(from,origin='1970-01-01')),'-',)[[1]][2])-1
        from.d <- as.numeric(strsplit(as.character(as.Date(from,origin='1970-01-01')),'-',)[[1]][3])
        to.y <- as.numeric(strsplit(as.character(as.Date(to,origin='1970-01-01')),'-',)[[1]][1])
        to.m <- as.numeric(strsplit(as.character(as.Date(to,origin='1970-01-01')),'-',)[[1]][2])-1
        to.d <- as.numeric(strsplit(as.character(as.Date(to,origin='1970-01-01')),'-',)[[1]][3])
-
+       
        Symbols.name <- getSymbolLookup()[[Symbols[[i]]]]$name
        Symbols.name <- ifelse(is.null(Symbols.name),Symbols[[i]],Symbols.name)
        if(verbose) cat("downloading ",Symbols.name,".....\n\n")
@@ -275,22 +278,14 @@ function(Symbols,env,return.class='xts',index.class="Date",
                              sep='.')
        if(adjust) {
          # Adjustment algorithm by Joshua Ulrich
-         div <- getDividends(Symbols.name, from=from, to=to, auto.assign=FALSE)
-         spl <- getSplits(Symbols.name,    from=from, to=to, auto.assign=FALSE)
-         adj <- na.omit(adjRatios(spl, div, Cl(fr)))
-
-         fr[,1] <- fr[,1] * adj[,'Split'] * adj[,'Div']  # Open
-         fr[,2] <- fr[,2] * adj[,'Split'] * adj[,'Div']  # High
-         fr[,3] <- fr[,3] * adj[,'Split'] * adj[,'Div']  # Low
-         fr[,4] <- fr[,4] * adj[,'Split'] * adj[,'Div']  # Close
-         fr[,5] <- fr[,5] * ( 1 / adj[,'Div'] )          # Volume
+         fr <- adjustOHLC(fr, symbol.name=Symbols.name)
        }
 
        fr <- convert.time.series(fr=fr,return.class=return.class)
        if(is.xts(fr))
          indexClass(fr) <- index.class
 
-       Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]]))
+       Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]])) 
        if(auto.assign)
          assign(Symbols[[i]],fr,env)
        if(i >= 5 && length(Symbols) > 5) {
@@ -312,13 +307,14 @@ function(Symbols,env,return.class='xts',
          ...)
 {
      fix.google.bug <- TRUE
+     importDefaults("getSymbols.google")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
         assign(var, list(...)[[var]], this.env)
      }
-     if(missing(verbose)) verbose <- FALSE
-     if(missing(auto.assign)) auto.assign <- TRUE
+     if(!hasArg(verbose)) verbose <- FALSE
+     if(!hasArg(auto.assign)) auto.assign <- TRUE
      google.URL <- "http://finance.google.com/finance/historical?"
      from.y <- as.numeric(strsplit(as.character(from),'-',)[[1]][1])
      from.m <- as.numeric(strsplit(as.character(from),'-',)[[1]][2])
@@ -363,7 +359,7 @@ function(Symbols,env,return.class='xts',
        # convert '-' to NAs
        suppressWarnings(storage.mode(fr) <- "numeric")
        fr <- convert.time.series(fr=fr,return.class=return.class)
-       Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]]))
+       Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]])) 
        if(auto.assign)
          assign(Symbols[[i]],fr,env)
      }
@@ -381,13 +377,14 @@ function(Symbols,env,return.class='xts',
                                dbname=NULL,
                                POSIX = TRUE,
                                ...) {
+     importDefaults("getSymbols.SQLite")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
         assign(var, list(...)[[var]], this.env)
      }
-     if(missing(verbose)) verbose <- FALSE
-     if(missing(auto.assign)) auto.assign <- TRUE
+     if(!hasArg(verbose)) verbose <- FALSE
+     if(!hasArg(auto.assign)) auto.assign <- TRUE
         if('package:DBI' %in% search() || require('DBI',quietly=TRUE)) {
           if('package:RSQLite' %in% search() || require('RSQLite',quietly=TRUE)) {
           } else { warning(paste("package:",dQuote("RSQLite"),"cannot be loaded" )) }
@@ -444,13 +441,14 @@ function(Symbols,env,return.class='xts',
                                field.names = NULL,
                                user=NULL,password=NULL,dbname=NULL,host='localhost',port=3306,
                                ...) {
+     importDefaults("getSymbols.MySQL")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
         assign(var, list(...)[[var]], this.env)
      }
-     if(missing(verbose)) verbose <- FALSE
-     if(missing(auto.assign)) auto.assign <- TRUE
+     if(!hasArg(verbose)) verbose <- FALSE
+     if(!hasArg(auto.assign)) auto.assign <- TRUE
         if('package:DBI' %in% search() || require('DBI',quietly=TRUE)) {
           if('package:RMySQL' %in% search() || require('RMySQL',quietly=TRUE)) {
           } else { warning(paste("package:",dQuote("RMySQL"),"cannot be loaded" )) }
@@ -500,13 +498,14 @@ function(Symbols,env,return.class='xts',
 # getSymbols.FRED {{{
 `getSymbols.FRED` <- function(Symbols,env,
      return.class="xts", ...) {
+     importDefaults("getSymbols.FRED")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
         assign(var, list(...)[[var]], this.env)
      }
-     if(missing(verbose)) verbose <- FALSE
-     if(missing(auto.assign)) auto.assign <- TRUE
+     if(!hasArg(verbose)) verbose <- FALSE
+     if(!hasArg(auto.assign)) auto.assign <- TRUE
      FRED.URL <- "http://research.stlouisfed.org/fred2/series"
      for(i in 1:length(Symbols)) {
        if(verbose) cat("downloading ",Symbols[[i]],".....\n\n")
@@ -525,7 +524,7 @@ function(Symbols,env,return.class='xts',
        dim(fr) <- c(NROW(fr),1)
        colnames(fr) <- as.character(toupper(Symbols[[i]]))
        fr <- convert.time.series(fr=fr,return.class=return.class)
-       Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]]))
+       Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]])) 
        if(auto.assign)
          assign(Symbols[[i]],fr,env)
      }
@@ -542,6 +541,7 @@ function(Currencies,from=Sys.Date()-499,to=Sys.Date(),
          env=parent.frame(),
          verbose=FALSE,warning=TRUE,
          auto.assign=TRUE,...) {
+  importDefaults("getFX")
   if(missing(env))
     env <- parent.frame(1)
   if(is.null(env))
@@ -561,7 +561,7 @@ function(Currencies,from=Sys.Date()-499,to=Sys.Date(),
                    auto.assign=auto.assign,...)
   #} else {
   #  getSymbols.FRED(Symbols=Currencies,env=env,verbose=verbose,warning=warning,...)
-  #}
+  #}  
 }
 #}}}
 
@@ -571,6 +571,7 @@ function(Metals,from=Sys.Date()-500,to=Sys.Date(),
          base.currency="USD",env=parent.frame(),
          verbose=FALSE,warning=TRUE,
          auto.assign=TRUE,...) {
+  importDefaults("getMetals")
   if(missing(env))
     env <- parent.frame(1)
   if(is.null(env))
@@ -582,7 +583,7 @@ function(Metals,from=Sys.Date()-500,to=Sys.Date(),
                      paste(strsplit(x,'-')[[1]][1],base.currency,sep="/")
                    }))
   getSymbols.oanda(Symbols=metals,from=from,to=to,auto.assign=auto.assign,
-                   env=env,verbose=verbose,warning=warning,...)
+                   env=env,verbose=verbose,warning=warning,...) 
 }
 #}}}
 
@@ -600,6 +601,7 @@ function(Symbols,env,
          return.class="xts",
          extension="csv",
          ...) {
+  importDefaults("getSymbols.csv")
   this.env <- environment()
   for(var in names(list(...))) {
     assign(var,list(...)[[var]], this.env)
@@ -609,8 +611,8 @@ function(Symbols,env,
   default.dir <- dir
   default.extension <- extension
 
-  if(missing(verbose)) verbose <- FALSE
-  if(missing(auto.assign)) auto.assign <- TRUE
+  if(!hasArg(verbose)) verbose <- FALSE
+  if(!hasArg(auto.assign)) auto.assign <- TRUE
 
   for(i in 1:length(Symbols)) {
     return.class <- getSymbolLookup()[[Symbols[[i]]]]$return.class
@@ -622,7 +624,7 @@ function(Symbols,env,
     extension <- getSymbolLookup()[[Symbols[[i]]]]$extension
     extension <- ifelse(is.null(extension),default.extension,
                            extension)
-
+                   
     format <- getSymbolLookup()[[Symbols[[i]]]]$format
     if(is.null(format)) format<-''
 ##    if(!is.null(list(...)[['format']])) {
@@ -642,14 +644,14 @@ function(Symbols,env,
       next
     }
     fr <- read.csv(sym.file)
-    if(verbose)
+    if(verbose)  
       cat("done.\n")
     fr <- xts(fr[,-1],as.Date(fr[,1],format=format, origin='1970-01-01'),src='csv',updated=Sys.time())
     colnames(fr) <- paste(toupper(gsub('\\^','',Symbols[[i]])),
                           c('Open','High','Low','Close','Volume','Adjusted'),
                              sep='.')
     fr <- convert.time.series(fr=fr,return.class=return.class)
-    Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]]))
+    Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]])) 
     if(auto.assign)
       assign(Symbols[[i]],fr,env)
     }
@@ -667,6 +669,7 @@ function(Symbols,env,
          extension="rds",
          col.names=c('Open','High','Low','Close','Volume','Adjusted'),
          ...) {
+  importDefaults("getSymbols.rds")
   this.env <- environment()
   for(var in names(list(...))) {
     assign(var,list(...)[[var]], this.env)
@@ -676,8 +679,8 @@ function(Symbols,env,
   default.dir <- dir
   default.extension <- extension
 
-  if(missing(verbose)) verbose <- FALSE
-  if(missing(auto.assign)) auto.assign <- TRUE
+  if(!hasArg(verbose)) verbose <- FALSE
+  if(!hasArg(auto.assign)) auto.assign <- TRUE
 
   for(i in 1:length(Symbols)) {
     return.class <- getSymbolLookup()[[Symbols[[i]]]]$return.class
@@ -702,12 +705,12 @@ function(Symbols,env,
     }
     #fr <- read.csv(sym.file)
     fr <- readRDS(sym.file)
-    if(verbose)
+    if(verbose)  
       cat("done.\n")
     if(!is.xts(fr)) fr <- xts(fr[,-1],as.Date(fr[,1],origin='1970-01-01'),src='rda',updated=Sys.time())
     colnames(fr) <- paste(toupper(gsub('\\^','',Symbols[[i]])),col.names,sep='.')
     fr <- convert.time.series(fr=fr,return.class=return.class)
-    Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]]))
+    Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]])) 
     if(auto.assign)
       assign(Symbols[[i]],fr,env)
     }
@@ -725,6 +728,7 @@ function(Symbols,env,
          extension="rda",
          col.names=c('Open','High','Low','Close','Volume','Adjusted'),
          ...) {
+  importDefaults("getSymbols.rda")
   this.env <- environment()
   for(var in names(list(...))) {
     assign(var,list(...)[[var]], this.env)
@@ -734,8 +738,8 @@ function(Symbols,env,
   default.dir <- dir
   default.extension <- extension
 
-  if(missing(verbose)) verbose <- FALSE
-  if(missing(auto.assign)) auto.assign <- TRUE
+  if(!hasArg(verbose)) verbose <- FALSE
+  if(!hasArg(auto.assign)) auto.assign <- TRUE
 
   for(i in 1:length(Symbols)) {
     return.class <- getSymbolLookup()[[Symbols[[i]]]]$return.class
@@ -761,12 +765,12 @@ function(Symbols,env,
     #fr <- read.csv(sym.file)
     local.name <- load(sym.file)
     assign('fr',get(local.name))
-    if(verbose)
+    if(verbose)  
       cat("done.\n")
     if(!is.xts(fr)) fr <- xts(fr[,-1],as.Date(fr[,1],origin='1970-01-01'),src='rda',updated=Sys.time())
     colnames(fr) <- paste(toupper(gsub('\\^','',Symbols[[i]])),col.names,sep='.')
     fr <- convert.time.series(fr=fr,return.class=return.class)
-    Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]]))
+    Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]])) 
     if(auto.assign)
       assign(Symbols[[i]],fr,env)
     }
@@ -785,27 +789,28 @@ function(Symbols,env,
 endDateTime, barSize='1 day', duration='1 M',
 useRTH = '1', whatToShow = 'TRADES', time.format = '1', ...)
 {
+  importDefaults('getSymbols.IBrokers')
   this.env <- environment()
   for(var in names(list(...))) {
     assign(var, list(...)[[var]], this.env)
   }
-  if(missing(verbose))
+  if(!hasArg(verbose))
     verbose <- FALSE
-  if(missing(auto.assign))
+  if(!hasArg(auto.assign))
     auto.assign <- TRUE
   if(is.method.available("twsConnect","IBrokers")) {
     tws <- do.call('twsConnect',list(clientId=1001))
     on.exit(do.call('twsDisconnect',list(tws)))
-
+  
     if(missing(endDateTime)) endDateTime <- NULL
-
+  
     for(i in 1:length(Symbols)) {
       Contract <- getSymbolLookup()[[Symbols[i]]]$Contract
       if(inherits(Contract,'twsContract')) {
         fr <- do.call('reqHistoricalData',list(tws, Contract, endDateTime=endDateTime,
                                 barSize=barSize, duration=duration,
                                 useRTH=useRTH, whatToShow=whatToShow,
-                                time.format=time.format, verbose=verbose))
+                                timeFormat=time.format, verbose=verbose))
         fr <- convert.time.series(fr=fr, return.class=return.class)
         if(auto.assign)
           assign(Symbols[[i]], fr, env)
@@ -823,7 +828,7 @@ useRTH = '1', whatToShow = 'TRADES', time.format = '1', ...)
     }
     if(auto.assign)
       return(Symbols)
-    return(fr)
+    return(fr) 
   }
 }
 # }}}
@@ -858,6 +863,7 @@ function(Symbols,env,return.class='xts',
          from=Sys.Date()-499,
          to=Sys.Date(),
          ...) {
+     importDefaults("getSymbols.oanda")
      if( (as.Date(to)-as.Date(from)) > 500 )
        stop("oanda.com limits data to 500 days per request", call.=FALSE)
      this.env <- environment()
@@ -872,8 +878,8 @@ function(Symbols,env,return.class='xts',
      default.from <- from
      default.to <- to
 
-     if(missing(verbose)) verbose <- FALSE
-     if(missing(auto.assign)) auto.assign <- TRUE
+     if(!hasArg(verbose)) verbose <- FALSE
+     if(!hasArg(auto.assign)) auto.assign <- TRUE
 
      oanda.URL <- "http://www.oanda.com/convert/fxhistory?lang=en&"
      for(i in 1:length(Symbols)) {
@@ -884,14 +890,14 @@ function(Symbols,env,return.class='xts',
        from <- ifelse(is.null(from),default.from,from)
        to <- getSymbolLookup()[[Symbols[[i]]]]$to
        to <- ifelse(is.null(to),default.to,to)
-
+   
        if(as.Date(to,origin='1970-01-01')-as.Date(from,origin='1970-01-01') > 499) stop("oanda limits data to 500 days")
        # automatically break larger requests into equal sized smaller request at some point
        # for now just let it remain
 
        from.date <- format(as.Date(from,origin='1970-01-01'),"date1=%m%%2F%d%%2F%y&")
        to.date <- format(as.Date(to,origin='1970-01-01'),"date=%m%%2F%d%%2F%y&date_fmt=us&")
-
+       
        Symbols.name <- getSymbolLookup()[[Symbols[[i]]]]$name
        Symbols.name <- ifelse(is.null(Symbols.name),Symbols[[i]],Symbols.name)
        currency.pair <- strsplit(toupper(Symbols.name),"/")[[1]]
@@ -906,7 +912,7 @@ function(Symbols,env,return.class='xts',
                        "&expr2=",currency.pair[2],
                        "&margin_fixed=0&SUBMIT=Get+Table&format=CSV&redirected=1",
                        sep=""),destfile=tmp,quiet=!verbose)
-       fr <- readLines(tmp)
+       fr <- readLines(tmp, warn=FALSE)
        unlink(tmp)
        fr <- unlist(strsplit(
                     gsub("<PRE>|</PRE>","",fr[(grep("PRE",fr)[1]):(grep("PRE",fr)[2])]),","))
@@ -917,7 +923,7 @@ function(Symbols,env,return.class='xts',
        dim(fr) <- c(length(fr),1)
        colnames(fr) <- gsub("/",".",Symbols[[i]])
        fr <- convert.time.series(fr=fr,return.class=return.class)
-       Symbols[[i]] <-toupper(gsub('\\^|/','',Symbols[[i]]))
+       Symbols[[i]] <-toupper(gsub('\\^|/','',Symbols[[i]])) 
        if(auto.assign)
          assign(Symbols[[i]],fr,env)
      }
@@ -959,15 +965,20 @@ function(Symbols,env,return.class='xts',
            warning(paste("'its' from package 'its' could not be loaded:",
                          " 'xts' class returned"))
          }
-       } else
+       } else 
        if('timeSeries' %in% return.class) {
+         if("package:timeSeries" %in% search() || suppressMessages(require("timeSeries",quietly=TRUE))) {
            fr <- timeSeries::timeSeries(coredata(fr), charvec=as.character(index(fr)))
            return(fr)
+         } else {
+           warning(paste("'timeSeries' from package 'timeSeries' could not be loaded:",
+                   " 'xts' class returned"))
+         }
        }
 }#}}}
 
 # removeSymbols {{{
-"removeSymbols" <-
+"removeSymbols" <- 
 function(Symbols=NULL,env=parent.frame()) {
     if(exists('.getSymbols',env,inherits=FALSE)) {
     getSymbols <- get('.getSymbols',env,inherits=FALSE)
@@ -1013,8 +1024,8 @@ function(Symbols=NULL,file.path=stop("must specify 'file.path'"),env=parent.fram
     for(each.symbol in Symbols) {
       save(list=each.symbol,
            file=paste(file.path,'/',each.symbol,".RData",sep=''),
-           env=env)
-    }
+           envir=env)
+    }    
   }
 }
 # }}}
